aboutsummaryrefslogtreecommitdiff
path: root/engines/tsage/ringworld/ringworld_logic.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/tsage/ringworld/ringworld_logic.h')
-rw-r--r--engines/tsage/ringworld/ringworld_logic.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/engines/tsage/ringworld/ringworld_logic.h b/engines/tsage/ringworld/ringworld_logic.h
index 0ff5428e8a..66084c7915 100644
--- a/engines/tsage/ringworld/ringworld_logic.h
+++ b/engines/tsage/ringworld/ringworld_logic.h
@@ -29,7 +29,9 @@
#include "tsage/scenes.h"
#include "tsage/globals.h"
-namespace tSage_Ringworld {
+namespace tSage {
+
+namespace Ringworld {
using namespace tSage;
@@ -440,7 +442,7 @@ public:
virtual Common::String getClassName() { return "RingworldInvObjectList"; }
};
-#define RING_INVENTORY (*((tSage_Ringworld::RingworldInvObjectList *)_globals->_inventory))
+#define RING_INVENTORY (*((::tSage::Ringworld::RingworldInvObjectList *)_globals->_inventory))
class RingworldGame: public Game {
protected:
@@ -458,6 +460,8 @@ public:
virtual void processEvent(Event &event);
};
-} // End of namespace tSage_Ringworld
+} // End of namespace Ringworld
+
+} // End of namespace tSage
#endif